@@ -116,7 +116,7 @@ class ckbytelist(PyKCS11.LowLevel.ckbytelist):
         return the representation of a tuple
         the __str__ method will use it also
         """
-        rep = [elt for elt in self]
+        rep = [int(elt) for elt in self]
         return repr(rep)
 
 
@@ -441,10 +441,15 @@ class PyKCS11Error(Exception):
         The text representation of a PKCS#11 error is something like:
         "CKR_DEVICE_ERROR (0x00000030)"
         """
-        if (self.value < 0):
-            return CKR[self.value] + " (%s)" % self.text
+        if self.value in CKR:
+            if self.value < 0:
+                return CKR[self.value] + " (%s)" % self.text
+            else:
+                return CKR[self.value] + " (0x%08X)" % self.value
+        elif self.value & CKR_VENDOR_DEFINED:
+            return "Vendor error (0x%08X)" % (self.value & 0xffffffff & ~CKR_VENDOR_DEFINED)
         else:
-            return CKR[self.value] + " (0x%08X)" % self.value
+            return "Unknown error (0x%08X)" % self.value
 
 
 class PyKCS11Lib(object):
@@ -962,7 +967,7 @@ class Session(object):
         @param mecha: the digesting mechanism to be used
         @type mecha: L{Mechanism} instance or L{MechanismSHA1}
         for CKM_SHA_1
-        @return: A DigestSession object
+        @return: A L{DigestSession} object
         @rtype: DigestSession
         """
         return DigestSession(self.lib, self.session, mecha)
@@ -981,6 +986,8 @@ class Session(object):
 
         @note: the returned value is an istance of L{ckbytelist}.
         You can easly convert it to a binary string with::
+            bytes(ckbytelistDigest)
+        or, for Python 2::
             ''.join(chr(i) for i in ckbytelistDigest)
 
         """
@@ -1016,6 +1023,8 @@ class Session(object):
 
         @note: the returned value is an instance of L{ckbytelist}.
         You can easly convert it to a binary string with::
+            bytes(ckbytelistSignature)
+        or, for Python 2::
             ''.join(chr(i) for i in ckbytelistSignature)
 
         """
@@ -1081,6 +1090,8 @@ class Session(object):
 
         @note: the returned value is an instance of L{ckbytelist}.
         You can easly convert it to a binary string with::
+            bytes(ckbytelistEncrypted)
+        or, for Python 2::
             ''.join(chr(i) for i in ckbytelistEncrypted)
 
         """
@@ -1116,6 +1127,8 @@ class Session(object):
 
         @note: the returned value is an instance of L{ckbytelist}.
         You can easly convert it to a binary string with::
+            bytes(ckbytelistData)
+        or, for Python 2::
             ''.join(chr(i) for i in ckbytelistData)
 
         """
@@ -1151,6 +1164,8 @@ class Session(object):
 
         @note: the returned value is an instance of L{ckbytelist}.
         You can easily convert it to a binary string with::
+            bytes(ckbytelistData)
+        or, for Python 2::
             ''.join(chr(i) for i in ckbytelistData)
 
         """
@@ -1377,9 +1392,12 @@ class Session(object):
 
         @note: if allAsBinary is True the function do not convert results to
         Python types (i.e.: CKA_TOKEN to Bool, CKA_CLASS to int, ...).
+
         Binary data is returned as L{ckbytelist} type, usable
         as a list containing only bytes.
         You can easly convert it to a binary string with::
+            bytes(ckbytelistVariable)
+        or, for Python 2::
             ''.join(chr(i) for i in ckbytelistVariable)
 
         """
@@ -1388,8 +1406,8 @@ class Session(object):
             valTemplate[x].SetType(attr[x])
         # first call to get the attribute size and reserve the memory
         rv = self.lib.C_GetAttributeValue(self.session, obj_id, valTemplate)
-        if rv == CKR_ATTRIBUTE_TYPE_INVALID \
-           or rv == CKR_ATTRIBUTE_SENSITIVE:
+        if rv in (CKR_ATTRIBUTE_TYPE_INVALID, CKR_ATTRIBUTE_SENSITIVE,
+                  CKR_ARGUMENTS_BAD):
             return self.getAttributeValue_fragmented(obj_id, attr, allAsBinary)
 
         if rv != CKR_OK:
@@ -1401,7 +1419,7 @@ class Session(object):
 
         res = []
         for x in range(len(attr)):
-            if (allAsBinary):
+            if allAsBinary:
                 res.append(valTemplate[x].GetBin())
             elif valTemplate[x].IsNum():
                 res.append(valTemplate[x].GetNum())
@@ -1434,8 +1452,8 @@ class Session(object):
             valTemplate[0].SetType(attr[x])
             # first call to get the attribute size and reserve the memory
             rv = self.lib.C_GetAttributeValue(self.session, obj_id, valTemplate)
-            if rv == CKR_ATTRIBUTE_TYPE_INVALID \
-               or rv == CKR_ATTRIBUTE_SENSITIVE:
+            if rv in (CKR_ATTRIBUTE_TYPE_INVALID,
+                      CKR_ATTRIBUTE_SENSITIVE, CKR_ARGUMENTS_BAD):
                 # append an empty value
                 res.append(None)
                 continue
@@ -1447,7 +1465,7 @@ class Session(object):
             if rv != CKR_OK:
                 raise PyKCS11Error(rv)
 
-            if (allAsBinary):
+            if allAsBinary:
                 res.append(valTemplate[0].GetBin())
             elif valTemplate[0].IsNum():
                 res.append(valTemplate[0].GetNum())
@@ -1469,9 +1487,7 @@ class Session(object):
         @param seed: seed material
         @type seed: iterable
         """
-        low_seed = ckbytelist(len(seed))
-        for c in range(len(seed)):
-            low_seed.append(seed[c])
+        low_seed = ckbytelist(seed)
         rv = self.lib.C_SeedRandom(self.session, low_seed)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
@@ -1485,6 +1501,8 @@ class Session(object):
 
         @note: the returned value is an instance of L{ckbytelist}.
         You can easly convert it to a binary string with::
+            bytes(random)
+        or, for Python 2::
             ''.join(chr(i) for i in random)
         """
         low_rand = ckbytelist(size)
