@@ -19,17 +19,20 @@
 from __future__ import print_function
 
 import PyKCS11.LowLevel
+import os
 
 a = PyKCS11.LowLevel.CPKCS11Lib()
 info = PyKCS11.LowLevel.CK_INFO()
 slotInfo = PyKCS11.LowLevel.CK_SLOT_INFO()
-lib = "/usr/lib/pkcs11/opensc-pkcs11.so"
+lib = os.getenv("PYKCS11LIB")
+if lib == None:
+    raise(Exception("Define PYKCS11LIB"))
 session = PyKCS11.LowLevel.CK_SESSION_HANDLE()
 slotList = PyKCS11.LowLevel.ckintlist()
 rand = PyKCS11.LowLevel.ckbytelist(20)
 seed = PyKCS11.LowLevel.ckbytelist(5)
 
-print("Load of " + lib + ": " + str(a.Load(lib, True)))
+print("Load of " + lib + ": " + str(a.Load(lib)))
 print("C_GetInfo: " + hex(a.C_GetInfo(info)))
 print("Library manufacturerID: " + info.GetManufacturerID())
 del info
