@@ -51,7 +51,7 @@ CPKCS11Lib::~CPKCS11Lib(void)
 	Unload();
 }
 
-bool CPKCS11Lib::Load(const char* szLib, bool bAutoCallInitialize)
+bool CPKCS11Lib::Load(const char* szLib)
 {
 	CK_RV rv;
 	Unload();
@@ -73,16 +73,11 @@ bool CPKCS11Lib::Load(const char* szLib, bool bAutoCallInitialize)
 		return false;
 	}
 
-	if (bAutoCallInitialize)
-	{
-		CK_INFO infos;
-		if (m_pFunc->C_GetInfo(&infos) == CKR_CRYPTOKI_NOT_INITIALIZED)
-		{
-			m_bAutoInitialized = m_bFinalizeOnClose = CKR_OK == m_pFunc->C_Initialize(NULL);
-		}
-		else
-			m_bAutoInitialized = true;
-	}
+	rv = m_pFunc->C_Initialize(NULL);
+	if (CKR_OK != rv  && CKR_CRYPTOKI_ALREADY_INITIALIZED != rv)
+		return false;
+
+	m_bFinalizeOnClose = true;
 	return true;
 }
 
